# Grepy

![CodeQL](https://github.com/UltiRequiem/grepy/workflows/CodeQL/badge.svg)
![PyTest](https://github.com/UltiRequiem/grepy/workflows/PyTest/badge.svg)
![Pylint](https://github.com/UltiRequiem/grepy/workflows/Pylint/badge.svg)
[![Code Style](https://img.shields.io/badge/Code%20Style-Black-000000.svg)](https://github.com/psf/black)
[![PyPi Version](https://img.shields.io/pypi/v/grepy)](https://pypi.org/project/grepy)
![Repo Size](https://img.shields.io/github/repo-size/ultirequiem/grepy?style=flat-square&label=Repo)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
![Lines of Code](https://img.shields.io/tokei/lines/github.com/UltiRequiem/grepy?color=blue&label=Total%20Lines)

A Python clone of [Grep](https://en.wikipedia.org/wiki/Grep).

## Install

You can install [grepy](https://pypi.org/project/grepy) from PyPI like any other package:

```bash
pip install grepy
```

To get the last version:

```bash
pip install git+https:/github.com/UltiRequiem/grepy
```

If you use Linux, you may need to install this with sudo to
be able to access the command throughout your system.

## Usage

Same as Grep:

```bash
grepy "String to grep" file_to_grep.py
```

### License

Grepy is licensed under the [MIT License](./LICENSE).
